@@ -1,6 +1,7 @@
 #include "monitor.ih"
 
 int Monitor::suppressorPid()
+try
 {
     ifstream runFile;
     Errno::open(runFile, Lock::runFilename());
@@ -10,3 +11,7 @@ int Monitor::suppressorPid()
 
     return pid;
 }
+catch (...)
+{
+    return 0;        
+}
