@@ -7,16 +7,15 @@ void Scanner::preamble()
 
                                 // try to echo a sentinel by having
                                 // the ssh connection echo it    
-    Util::debug() << "Inserting " << d_sentinel << " into " << 
-                    d_sorter["SSH"] << endl;
+    imsg << "Inserting " << d_sentinel << " into " << d_sorter["SSH"] << endl;
 
-    d_sshFork << "/bin/echo \"" << d_sentinel << "\"" << endl;
+    d_sshFork << "/bin/echo \"" << d_sentinel << "\"" << endl;   // must flush
 
-    Util::debug() << "Waiting for " << d_sentinel << " from " << 
-                                                d_sorter["SSH"] << endl;
+    imsg << "Waiting for " << d_sentinel << " from " << d_sorter["SSH"] << 
+                                                                        endl;
 
     d_testExitValue = false;
     waitForSentinel(d_sshFork);  // continue after reading 
 
-    Util::debug() << d_sorter["SSH"] << " appears to be functioning well\n";
+    imsg << d_sorter["SSH"] << " appears to be functioning well" << endl;
 }
