@@ -10,6 +10,7 @@
 namespace FBB
 {
     class Pattern;
+    class Arg;
 }
 
 class ConfigSorter;
@@ -20,6 +21,7 @@ class Scanner
     typedef std::vector<std::string>     StringVector;
     typedef StringVector::const_iterator const_iterator;
 
+    FBB::Arg       &d_arg;
     ConfigSorter   &d_sorter;
     Reporter       &d_reporter;
     FBB::Pattern   &d_firstWord;
@@ -34,10 +36,11 @@ class Scanner
     std::string     d_maxSizeStr;
     bool            d_quit;
     StringVector    d_skipFiles;
+    std::string     d_skipFilePath;
                                         // the abs path is at the end of 
                                         // the line. Any text may precede
                                         // it
-    bool (Scanner::*d_skip)(std::string const &absPath);
+    bool (Scanner::*d_skip)(std::string &absPath);
 
     static FBB::Pattern  s_split;
     static FBB::Pattern  s_firstWord;
@@ -50,6 +53,8 @@ class Scanner
             return d_nScans;
         }
         void preamble();
+        void loadSkipFiles();
+        void nScansReset();
                                     // run one series of tests
         void        run(volatile bool *done);    
 
@@ -139,14 +144,13 @@ class Scanner
         void        removeLOG();    // remove LOG = from current command
 
                                     // true if filename not in d_skipFiles
-        bool        skip(std::string const &line);
+        bool        skip(std::string &line);
 
                                     // always indicates "don't skip"
-        bool        dontSkip(std::string const &line);
+        bool        dontSkip(std::string &line);
 
                                     // fill the d_skipFiles vector and set
-                                    // d_skip to &skipING
-        void        setSkip(std::string const &fname);
+        void        setSkip();      // d_skip to &skipING
 
         static std::string fileName(std::string const &name);
         static std::string datetime();
@@ -155,10 +159,9 @@ class Scanner
         static void add(std::string const &line, StringVector &skipFiles);
 };
 
-inline bool Scanner::dontSkip(std::string const &line)
+inline void Scanner::nScansReset()
 {
-    return false;       // by returning false the question 
-                        // 'skip line?' is always answered as 'no'
+    d_nScans = 0;
 }
 
 #endif
